EventTarget

Struct EventTarget 

pub struct EventTarget { /* private fields */ }
The EventTarget class.

MDN Documentation

This API requires the following crate features to be activated: EventTarget

Implementations

Source

impl EventTarget

pub fn new() -> Result<EventTarget, JsValue>

The new EventTarget(..) constructor, creating a new instance of EventTarget.

MDN Documentation

This API requires the following crate features to be activated: EventTarget

Source

impl EventTarget

pub fn add_event_listener_with_callback( &self, type_: &str, listener: &Function, ) -> Result<(), JsValue>

The addEventListener() method.

MDN Documentation

This API requires the following crate features to be activated: EventTarget

Source

impl EventTarget

pub fn add_event_listener_with_callback_and_add_event_listener_options( &self, type_: &str, listener: &Function, options: &AddEventListenerOptions, ) -> Result<(), JsValue>

The addEventListener() method.

MDN Documentation

This API requires the following crate features to be activated: AddEventListenerOptions, EventTarget

Source

impl EventTarget

pub fn add_event_listener_with_callback_and_bool( &self, type_: &str, listener: &Function, options: bool, ) -> Result<(), JsValue>

The addEventListener() method.

MDN Documentation

This API requires the following crate features to be activated: EventTarget

Source

impl EventTarget

pub fn add_event_listener_with_callback_and_add_event_listener_options_and_wants_untrusted( &self, type_: &str, listener: &Function, options: &AddEventListenerOptions, wants_untrusted: Option<bool>, ) -> Result<(), JsValue>

The addEventListener() method.

MDN Documentation

This API requires the following crate features to be activated: AddEventListenerOptions, EventTarget

Source

impl EventTarget

pub fn add_event_listener_with_callback_and_bool_and_wants_untrusted( &self, type_: &str, listener: &Function, options: bool, wants_untrusted: Option<bool>, ) -> Result<(), JsValue>

The addEventListener() method.

MDN Documentation

This API requires the following crate features to be activated: EventTarget

Source

impl EventTarget

pub fn dispatch_event(&self, event: &Event) -> Result<bool, JsValue>

The dispatchEvent() method.

MDN Documentation

This API requires the following crate features to be activated: Event, EventTarget

Source

impl EventTarget

pub fn remove_event_listener_with_callback( &self, type_: &str, listener: &Function, ) -> Result<(), JsValue>

The removeEventListener() method.

MDN Documentation

This API requires the following crate features to be activated: EventTarget

Source

impl EventTarget

pub fn remove_event_listener_with_callback_and_bool( &self, type_: &str, listener: &Function, options: bool, ) -> Result<(), JsValue>

The removeEventListener() method.

MDN Documentation

This API requires the following crate features to be activated: EventTarget

Methods from Deref<Target = Object>

pub fn constructor(&self) -> Function

The constructor property returns a reference to the Object constructor function that created the instance object.

MDN documentation

pub fn has_own_property(&self, property: &JsValue) -> bool

The hasOwnProperty() method returns a boolean indicating whether the object has the specified property as its own property (as opposed to inheriting it).

MDN documentation

pub fn is_prototype_of(&self, value: &JsValue) -> bool

The isPrototypeOf() method checks if an object exists in another object’s prototype chain.

MDN documentation

pub fn property_is_enumerable(&self, property: &JsValue) -> bool

The propertyIsEnumerable() method returns a Boolean indicating whether the specified property is enumerable.

MDN documentation

pub fn to_locale_string(&self) -> JsString

The toLocaleString() method returns a string representing the object. This method is meant to be overridden by derived objects for locale-specific purposes.

MDN documentation

pub fn to_string(&self) -> JsString

The toString() method returns a string representing the object.

MDN documentation

pub fn value_of(&self) -> Object

The valueOf() method returns the primitive value of the specified object.

MDN documentation

Methods from Deref<Target = JsValue>

pub const NULL: JsValue

pub const UNDEFINED: JsValue

pub const TRUE: JsValue

pub const FALSE: JsValue

pub fn as_f64(&self) -> Option<f64>

Returns the f64 value of this JS value if it’s an instance of a number.

If this JS value is not an instance of a number then this returns None.

pub fn is_string(&self) -> bool

Tests whether this JS value is a JS string.

pub fn as_string(&self) -> Option<String>

If this JS value is a string value, this function copies the JS string value into Wasm linear memory, encoded as UTF-8, and returns it as a Rust String.

To avoid the copying and re-encoding, consider the JsString::try_from() function from js-sys instead.

If this JS value is not an instance of a string or if it’s not valid utf-8 then this returns None.

UTF-16 vs UTF-8

JavaScript strings in general are encoded as UTF-16, but Rust strings are encoded as UTF-8. This can cause the Rust string to look a bit different than the JS string sometimes. For more details see the documentation about the str type which contains a few caveats about the encodings.

pub fn as_bool(&self) -> Option<bool>

Returns the bool value of this JS value if it’s an instance of a boolean.

If this JS value is not an instance of a boolean then this returns None.

pub fn is_null(&self) -> bool

Tests whether this JS value is null

pub fn is_undefined(&self) -> bool

Tests whether this JS value is undefined

pub fn is_symbol(&self) -> bool

Tests whether the type of this JS value is symbol

pub fn is_object(&self) -> bool

Tests whether typeof self == "object" && self !== null.

pub fn is_array(&self) -> bool

Tests whether this JS value is an instance of Array.

pub fn is_function(&self) -> bool

Tests whether the type of this JS value is function.

pub fn is_bigint(&self) -> bool

Tests whether the type of this JS value is bigint.

pub fn js_typeof(&self) -> JsValue

Applies the unary typeof JS operator on a JsValue.

MDN documentation

pub fn js_in(&self, obj: &JsValue) -> bool

Applies the binary in JS operator on the two JsValues.

MDN documentation

pub fn is_truthy(&self) -> bool

Tests whether the value is “truthy”.

pub fn is_falsy(&self) -> bool

Tests whether the value is “falsy”.

pub fn loose_eq(&self, other: &JsValue) -> bool

Compare two JsValues for equality, using the == operator in JS.

MDN documentation

pub fn bit_not(&self) -> JsValue

Applies the unary ~ JS operator on a JsValue.

MDN documentation

pub fn unsigned_shr(&self, rhs: &JsValue) -> u32

Applies the binary >>> JS operator on the two JsValues.

MDN documentation

pub fn checked_div(&self, rhs: &JsValue) -> JsValue

Applies the binary / JS operator on two JsValues, catching and returning any RangeError thrown.

MDN documentation

pub fn pow(&self, rhs: &JsValue) -> JsValue

Applies the binary ** JS operator on the two JsValues.

MDN documentation

pub fn lt(&self, other: &JsValue) -> bool

Applies the binary < JS operator on the two JsValues.

MDN documentation

pub fn le(&self, other: &JsValue) -> bool

Applies the binary <= JS operator on the two JsValues.

MDN documentation

pub fn ge(&self, other: &JsValue) -> bool

Applies the binary >= JS operator on the two JsValues.

MDN documentation

pub fn gt(&self, other: &JsValue) -> bool

Applies the binary > JS operator on the two JsValues.

MDN documentation

pub fn unchecked_into_f64(&self) -> f64

Applies the unary + JS operator on a JsValue. Can throw.

MDN documentation