Node

Struct Node 

pub struct Node { /* private fields */ }
The Node class.

MDN Documentation

This API requires the following crate features to be activated: Node

Implementations

Source

impl Node

pub fn node_type(&self) -> u16

Getter for the nodeType field of this object.

MDN Documentation

This API requires the following crate features to be activated: Node

Source

impl Node

pub fn node_name(&self) -> String

Getter for the nodeName field of this object.

MDN Documentation

This API requires the following crate features to be activated: Node

Source

impl Node

pub fn base_uri(&self) -> Result<Option<String>, JsValue>

Getter for the baseURI field of this object.

MDN Documentation

This API requires the following crate features to be activated: Node

Source

impl Node

pub fn is_connected(&self) -> bool

Getter for the isConnected field of this object.

MDN Documentation

This API requires the following crate features to be activated: Node

Source

impl Node

pub fn owner_document(&self) -> Option<Document>

Getter for the ownerDocument field of this object.

MDN Documentation

This API requires the following crate features to be activated: Document, Node

Source

impl Node

pub fn parent_node(&self) -> Option<Node>

Getter for the parentNode field of this object.

MDN Documentation

This API requires the following crate features to be activated: Node

Source

impl Node

pub fn parent_element(&self) -> Option<Element>

Getter for the parentElement field of this object.

MDN Documentation

This API requires the following crate features to be activated: Element, Node

Source

impl Node

pub fn first_child(&self) -> Option<Node>

Getter for the firstChild field of this object.

MDN Documentation

This API requires the following crate features to be activated: Node

Source

impl Node

pub fn last_child(&self) -> Option<Node>

Getter for the lastChild field of this object.

MDN Documentation

This API requires the following crate features to be activated: Node

Source

impl Node

pub fn previous_sibling(&self) -> Option<Node>

Getter for the previousSibling field of this object.

MDN Documentation

This API requires the following crate features to be activated: Node

Source

impl Node

pub fn next_sibling(&self) -> Option<Node>

Getter for the nextSibling field of this object.

MDN Documentation

This API requires the following crate features to be activated: Node

Source

impl Node

pub fn node_value(&self) -> Option<String>

Getter for the nodeValue field of this object.

MDN Documentation

This API requires the following crate features to be activated: Node

Source

impl Node

pub fn set_node_value(&self, value: Option<&str>)

Setter for the nodeValue field of this object.

MDN Documentation

This API requires the following crate features to be activated: Node

Source

impl Node

pub fn text_content(&self) -> Option<String>

Getter for the textContent field of this object.

MDN Documentation

This API requires the following crate features to be activated: Node

Source

impl Node

pub fn set_text_content(&self, value: Option<&str>)

Setter for the textContent field of this object.

MDN Documentation

This API requires the following crate features to be activated: Node

Source

impl Node

pub fn append_child(&self, node: &Node) -> Result<Node, JsValue>

The appendChild() method.

MDN Documentation

This API requires the following crate features to be activated: Node

Source

impl Node

pub fn clone_node(&self) -> Result<Node, JsValue>

The cloneNode() method.

MDN Documentation

This API requires the following crate features to be activated: Node

Source

impl Node

pub fn clone_node_with_deep(&self, deep: bool) -> Result<Node, JsValue>

The cloneNode() method.

MDN Documentation

This API requires the following crate features to be activated: Node

Source

impl Node

pub fn compare_document_position(&self, other: &Node) -> u16

The compareDocumentPosition() method.

MDN Documentation

This API requires the following crate features to be activated: Node

Source

impl Node

pub fn contains(&self, other: Option<&Node>) -> bool

The contains() method.

MDN Documentation

This API requires the following crate features to be activated: Node

Source

impl Node

pub fn get_root_node(&self) -> Node

The getRootNode() method.

MDN Documentation

This API requires the following crate features to be activated: Node

Source

impl Node

pub fn has_child_nodes(&self) -> bool

The hasChildNodes() method.

MDN Documentation

This API requires the following crate features to be activated: Node

Source

impl Node

pub fn insert_before( &self, node: &Node, child: Option<&Node>, ) -> Result<Node, JsValue>

The insertBefore() method.

MDN Documentation

This API requires the following crate features to be activated: Node

Source

impl Node

pub fn is_default_namespace(&self, namespace: Option<&str>) -> bool

The isDefaultNamespace() method.

MDN Documentation

This API requires the following crate features to be activated: Node

Source

impl Node

pub fn is_equal_node(&self, node: Option<&Node>) -> bool

The isEqualNode() method.

MDN Documentation

This API requires the following crate features to be activated: Node

Source

impl Node

pub fn is_same_node(&self, node: Option<&Node>) -> bool

The isSameNode() method.

MDN Documentation

This API requires the following crate features to be activated: Node

Source

impl Node

pub fn lookup_namespace_uri(&self, prefix: Option<&str>) -> Option<String>

The lookupNamespaceURI() method.

MDN Documentation

This API requires the following crate features to be activated: Node

Source

impl Node

pub fn lookup_prefix(&self, namespace: Option<&str>) -> Option<String>

The lookupPrefix() method.

MDN Documentation

This API requires the following crate features to be activated: Node

Source

impl Node

pub fn normalize(&self)

The normalize() method.

MDN Documentation

This API requires the following crate features to be activated: Node

Source

impl Node

pub fn remove_child(&self, child: &Node) -> Result<Node, JsValue>

The removeChild() method.

MDN Documentation

This API requires the following crate features to be activated: Node

Source

impl Node

pub fn replace_child(&self, node: &Node, child: &Node) -> Result<Node, JsValue>

The replaceChild() method.

MDN Documentation

This API requires the following crate features to be activated: Node

Source

impl Node

pub const ELEMENT_NODE: u16 = 1u16

The Node.ELEMENT_NODE const.

This API requires the following crate features to be activated: Node

pub const ATTRIBUTE_NODE: u16 = 2u16

The Node.ATTRIBUTE_NODE const.

This API requires the following crate features to be activated: Node

pub const TEXT_NODE: u16 = 3u16

The Node.TEXT_NODE const.

This API requires the following crate features to be activated: Node

pub const CDATA_SECTION_NODE: u16 = 4u16

The Node.CDATA_SECTION_NODE const.

This API requires the following crate features to be activated: Node

pub const ENTITY_REFERENCE_NODE: u16 = 5u16

The Node.ENTITY_REFERENCE_NODE const.

This API requires the following crate features to be activated: Node

pub const ENTITY_NODE: u16 = 6u16

The Node.ENTITY_NODE const.

This API requires the following crate features to be activated: Node

pub const PROCESSING_INSTRUCTION_NODE: u16 = 7u16

The Node.PROCESSING_INSTRUCTION_NODE const.

This API requires the following crate features to be activated: Node

pub const COMMENT_NODE: u16 = 8u16

The Node.COMMENT_NODE const.

This API requires the following crate features to be activated: Node

pub const DOCUMENT_NODE: u16 = 9u16

The Node.DOCUMENT_NODE const.

This API requires the following crate features to be activated: Node

pub const DOCUMENT_TYPE_NODE: u16 = 10u16

The Node.DOCUMENT_TYPE_NODE const.

This API requires the following crate features to be activated: Node

pub const DOCUMENT_FRAGMENT_NODE: u16 = 11u16

The Node.DOCUMENT_FRAGMENT_NODE const.

This API requires the following crate features to be activated: Node

pub const NOTATION_NODE: u16 = 12u16

The Node.NOTATION_NODE const.

This API requires the following crate features to be activated: Node

pub const DOCUMENT_POSITION_DISCONNECTED: u16 = 1u16

The Node.DOCUMENT_POSITION_DISCONNECTED const.

This API requires the following crate features to be activated: Node

pub const DOCUMENT_POSITION_PRECEDING: u16 = 2u16

The Node.DOCUMENT_POSITION_PRECEDING const.

This API requires the following crate features to be activated: Node

pub const DOCUMENT_POSITION_FOLLOWING: u16 = 4u16

The Node.DOCUMENT_POSITION_FOLLOWING const.

This API requires the following crate features to be activated: Node

pub const DOCUMENT_POSITION_CONTAINS: u16 = 8u16

The Node.DOCUMENT_POSITION_CONTAINS const.

This API requires the following crate features to be activated: Node

pub const DOCUMENT_POSITION_CONTAINED_BY: u16 = 16u16

The Node.DOCUMENT_POSITION_CONTAINED_BY const.

This API requires the following crate features to be activated: Node

pub const DOCUMENT_POSITION_IMPLEMENTATION_SPECIFIC: u16 = 32u16

The Node.DOCUMENT_POSITION_IMPLEMENTATION_SPECIFIC const.

This API requires the following crate features to be activated: Node

Methods from Deref<Target = EventTarget>

pub fn add_event_listener_with_callback( &self, type_: &str, listener: &Function, ) -> Result<(), JsValue>

The addEventListener() method.

MDN Documentation

This API requires the following crate features to be activated: EventTarget

pub fn add_event_listener_with_callback_and_add_event_listener_options( &self, type_: &str, listener: &Function, options: &AddEventListenerOptions, ) -> Result<(), JsValue>

The addEventListener() method.

MDN Documentation

This API requires the following crate features to be activated: AddEventListenerOptions, EventTarget

pub fn add_event_listener_with_callback_and_bool( &self, type_: &str, listener: &Function, options: bool, ) -> Result<(), JsValue>

The addEventListener() method.

MDN Documentation

This API requires the following crate features to be activated: EventTarget

pub fn add_event_listener_with_callback_and_add_event_listener_options_and_wants_untrusted( &self, type_: &str, listener: &Function, options: &AddEventListenerOptions, wants_untrusted: Option<bool>, ) -> Result<(), JsValue>

The addEventListener() method.

MDN Documentation

This API requires the following crate features to be activated: AddEventListenerOptions, EventTarget

pub fn add_event_listener_with_callback_and_bool_and_wants_untrusted( &self, type_: &str, listener: &Function, options: bool, wants_untrusted: Option<bool>, ) -> Result<(), JsValue>

The addEventListener() method.

MDN Documentation

This API requires the following crate features to be activated: EventTarget

pub fn dispatch_event(&self, event: &Event) -> Result<bool, JsValue>

The dispatchEvent() method.

MDN Documentation

This API requires the following crate features to be activated: Event, EventTarget

pub fn remove_event_listener_with_callback( &self, type_: &str, listener: &Function, ) -> Result<(), JsValue>

The removeEventListener() method.

MDN Documentation

This API requires the following crate features to be activated: EventTarget

pub fn remove_event_listener_with_callback_and_bool( &self, type_: &str, listener: &Function, options: bool, ) -> Result<(), JsValue>

The removeEventListener() method.

MDN Documentation

This API requires the following crate features to be activated: EventTarget

Methods from Deref<Target = Object>

pub fn constructor(&self) -> Function

The constructor property returns a reference to the Object constructor function that created the instance object.

MDN documentation

pub fn has_own_property(&self, property: &JsValue) -> bool

The hasOwnProperty() method returns a boolean indicating whether the object has the specified property as its own property (as opposed to inheriting it).

MDN documentation

pub fn is_prototype_of(&self, value: &JsValue) -> bool

The isPrototypeOf() method checks if an object exists in another object’s prototype chain.

MDN documentation

pub fn property_is_enumerable(&self, property: &JsValue) -> bool

The propertyIsEnumerable() method returns a Boolean indicating whether the specified property is enumerable.

MDN documentation

pub fn to_locale_string(&self) -> JsString

The toLocaleString() method returns a string representing the object. This method is meant to be overridden by derived objects for locale-specific purposes.

MDN documentation

pub fn to_string(&self) -> JsString

The toString() method returns a string representing the object.

MDN documentation

pub fn value_of(&self) -> Object

The valueOf() method returns the primitive value of the specified object.

MDN documentation

Methods from Deref<Target = JsValue>

pub const NULL: JsValue

pub const UNDEFINED: JsValue

pub const TRUE: JsValue

pub const FALSE: JsValue

pub fn as_f64(&self) -> Option<f64>

Returns the f64 value of this JS value if it’s an instance of a number.

If this JS value is not an instance of a number then this returns None.

pub fn is_string(&self) -> bool

Tests whether this JS value is a JS string.

pub fn as_string(&self) -> Option<String>

If this JS value is a string value, this function copies the JS string value into Wasm linear memory, encoded as UTF-8, and returns it as a Rust String.

To avoid the copying and re-encoding, consider the JsString::try_from() function from js-sys instead.

If this JS value is not an instance of a string or if it’s not valid utf-8 then this returns None.

UTF-16 vs UTF-8

JavaScript strings in general are encoded as UTF-16, but Rust strings are encoded as UTF-8. This can cause the Rust string to look a bit different than the JS string sometimes. For more details see the documentation about the str type which contains a few caveats about the encodings.

pub fn as_bool(&self) -> Option<bool>

Returns the bool value of this JS value if it’s an instance of a boolean.

If this JS value is not an instance of a boolean then this returns None.

pub fn is_null(&self) -> bool

Tests whether this JS value is null

pub fn is_undefined(&self) -> bool

Tests whether this JS value is undefined

pub fn is_symbol(&self) -> bool

Tests whether the type of this JS value is symbol

pub fn is_object(&self) -> bool

Tests whether typeof self == "object" && self !== null.

pub fn is_array(&self) -> bool

Tests whether this JS value is an instance of Array.

pub fn is_function(&self) -> bool

Tests whether the type of this JS value is function.

pub fn is_bigint(&self) -> bool

Tests whether the type of this JS value is bigint.

pub fn js_typeof(&self) -> JsValue

Applies the unary typeof JS operator on a JsValue.

MDN documentation

pub fn js_in(&self, obj: &JsValue) -> bool

Applies the binary in JS operator on the two JsValues.

MDN documentation

pub fn is_truthy(&self) -> bool

Tests whether the value is “truthy”.

pub fn is_falsy(&self) -> bool

Tests whether the value is “falsy”.

pub fn loose_eq(&self, other: &JsValue) -> bool

Compare two JsValues for equality, using the == operator in JS.

MDN documentation

pub fn bit_not(&self) -> JsValue

Applies the unary ~ JS operator on a JsValue.

MDN documentation

pub fn unsigned_shr(&self, rhs: &JsValue) -> u32

Applies the binary >>> JS operator on the two JsValues.

MDN documentation

pub fn checked_div(&self, rhs: &JsValue) -> JsValue

Applies the binary / JS operator on two JsValues, catching and returning any RangeError thrown.

MDN documentation

pub fn pow(&self, rhs: &JsValue) -> JsValue

Applies the binary ** JS operator on the two JsValues.

MDN documentation

pub fn lt(&self, other: &JsValue) -> bool

Applies the binary < JS operator on the two JsValues.

MDN documentation

pub fn le(&self, other: &JsValue) -> bool

Applies the binary <= JS operator on the two JsValues.

MDN documentation

pub fn ge(&self, other: &JsValue) -> bool

Applies the binary >= JS operator on the two JsValues.

MDN documentation

pub fn gt(&self, other: &JsValue) -> bool

Applies the binary > JS operator on the two JsValues.

MDN documentation

pub fn unchecked_into_f64(&self) -> f64

Applies the unary + JS operator on a JsValue. Can throw.

MDN documentation